import * as paraHP from '../interfaces';
import { BigNumber } from 'ethers';
import { SwapRebalance } from '../interfaces';
/**
 * Get the Delta between two Positions
 * @param from currentPositon
 * @param to DesiredPositons
 * @returns an array indicating the delta of each asset in the vault
 */
export declare const getDeltaProportion: (from: BigNumber[], to: BigNumber[]) => BigNumber[];
/**
 * Check that the sum of positions are equal to 10000
 * @param balance currentPositon
 * @returns an boolean indicating if the positions are well defined
 */
export declare const checkPropotions: (balance: BigNumber[]) => boolean;
/**
 * Get the index of the minimal debit
 * @param delta delta between the currentPositon and the desired Position
 * @returns a number
 */
export declare const minDebit: (delta: BigNumber[]) => number;
/**
 * Get the index of the maximal credit
 * @param delta delta between the currentPositon and the desired Position
 * @returns a number
 */
export declare const maxCredit: (delta: BigNumber[]) => number;
/**
 * Rebalance the proportion of results in the proportion of demand and the priority given to the small deficit
 * @param swapData SwapRebalance
 * @param networkID number TransactionsToParaswap[]
 * @returns an array of TransactionsToParaswap[]
 */
export declare const performFillTheMinFirst: (swapData: SwapRebalance, networkID: number) => Promise<paraHP.TransactionsToParaswap[]>;
/**
 * Rebalance the proportion of results in the proportion of demand based on the priority of the assets
 * @param swapData SwapRebalance
 * @returns an array of TransactionsToParaswap[]
 */
export declare const performNaiveRebalancing: (swapData: SwapRebalance, networkID: number) => Promise<paraHP.TransactionsToParaswap[]>;
/**
 * Getting paraswap transactions for Augustus contract
 * @param txs array of transactions to go given by performNaiveRebalancing or performFillTheMinFirst
 * @param networkID chainID
 * @param userAddress The address of the caller (usually the vault)
 * @param slippage slippage in BPS
 * @param maxImpact the maximal price imapct tolerated in BPS
 * @param receiver The address of the receiver of the swaps (usually the vault)
 * @returns an array containing the response of the API for each transactions
 */
export declare const formatQueriesForParaswap: (txs: paraHP.TransactionsToParaswap[], networkID: number, userAddress: string, slippage: string, maxImpact: string, receiver: string) => Promise<paraHP.TransactionParams[]>;
