import { BigNumber } from 'ethers';
import { OptimalRate } from 'paraswap-core';
import * as paraType from '../type';
export interface TransactionsToParaswap {
    srcToken: string;
    srcDecimal: number;
    destToken: string;
    destDecimal: number;
    amount: BigNumber;
}
export interface MinTokenData {
    decimals: number;
    address: string;
}
export interface GetSwapTxInput {
    srcToken: paraType.Address;
    destToken: paraType.Address;
    srcDecimal: number;
    destDecimal: number;
    srcAmount: paraType.NumberAsString;
    networkID: number;
    slippage: string;
    partner?: string;
    userAddress: paraType.Address;
    receiver: paraType.Address;
    maxImpact: string;
}
export interface TransactionParams {
    to: paraType.Address;
    from: paraType.Address;
    value: paraType.NumberAsString;
    data: string;
    gasPrice: paraType.NumberAsString;
    gas?: paraType.NumberAsString;
    chainId: number;
}
export interface Swapper {
    getRate(params: {
        srcToken: MinTokenData;
        destToken: MinTokenData;
        srcAmount: paraType.NumberAsString;
        maxImpact: string;
        partner?: string;
    }): Promise<OptimalRate>;
    buildSwap(params: {
        srcToken: MinTokenData;
        destToken: MinTokenData;
        srcAmount: paraType.NumberAsString;
        priceRoute: OptimalRate;
        userAddress: paraType.Address;
        receiver: paraType.Address;
        partner?: string;
        slippage: string;
    }): Promise<TransactionParams>;
}
